[SCM] ktp-text-ui packaging branch, master, updated. debian/15.12.1-1-1918-gdf4b0ec

Maximiliano Curia maxy at moszumanska.debian.org
Sat May 28 00:24:33 UTC 2016


Gitweb-URL: http://git.debian.org/?p=pkg-kde/applications/ktp-text-ui.git;a=commitdiff;h=9b883e1

The following commit has been merged in the master branch:
commit 9b883e19b8a37ef9e2fcc097ff828de76f66d2b5
Author: Daniele E. Domenichelli <daniele.domenichelli at iit.it>
Date:   Sun Apr 13 20:52:08 2014 +0200

    Support %serviceIconPath% replacement in adium themes
---
 lib/adium-theme-header-info.cpp | 10 +++++-----
 lib/adium-theme-header-info.h   |  6 +++---
 lib/adium-theme-view.cpp        |  3 ++-
 lib/chat-widget.cpp             |  2 +-
 4 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/lib/adium-theme-header-info.cpp b/lib/adium-theme-header-info.cpp
index 3dfa249..a4febf8 100644
--- a/lib/adium-theme-header-info.cpp
+++ b/lib/adium-theme-header-info.cpp
@@ -33,7 +33,7 @@ public:
     QUrl incomingIconPath;
     QUrl outgoingIconPath;
     QDateTime timeOpened;
-    QString serviceIconImg;
+    QString serviceIconPath;
     bool isGroupChat;
 };
 
@@ -133,14 +133,14 @@ void AdiumThemeHeaderInfo::setTimeOpened(const QDateTime& timeOpened)
     d->timeOpened = timeOpened;
 };
 
-QString AdiumThemeHeaderInfo::serviceIconImg() const
+QString AdiumThemeHeaderInfo::serviceIconPath() const
 {
-    return d->serviceIconImg;
+    return d->serviceIconPath;
 }
 
-void AdiumThemeHeaderInfo::setServiceIconImage(const QString& serviceIconImg)
+void AdiumThemeHeaderInfo::setServiceIconPath(const QString& serviceIconPath)
 {
-    d->serviceIconImg = serviceIconImg;
+    d->serviceIconPath = serviceIconPath;
 }
 
 bool AdiumThemeHeaderInfo::isGroupChat() const
diff --git a/lib/adium-theme-view.cpp b/lib/adium-theme-view.cpp
index 7e2595e..2b6e88f 100644
--- a/lib/adium-theme-view.cpp
+++ b/lib/adium-theme-view.cpp
@@ -685,7 +685,8 @@ QString AdiumThemeView::replaceHeaderKeywords(QString htmlTemplate, const AdiumT
         htmlTemplate.replace(pos , timeRegExp.cap(0).length() , timeKeyword);
     }
     htmlTemplate.replace(QLatin1String("%serviceIconImg%"),
-                         QString::fromLatin1("<img src=\"%1\" class=\"serviceIcon\" />").arg(info.serviceIconImg()));
+                         QString::fromLatin1("<img src=\"%1\" class=\"serviceIcon\" />").arg(info.serviceIconPath()));
+    htmlTemplate.replace(QLatin1String("%serviceIconPath%"), info.serviceIconPath());
     return htmlTemplate;
 }
 
diff --git a/lib/chat-widget.cpp b/lib/chat-widget.cpp
index 1b511ca..d130529 100644
--- a/lib/chat-widget.cpp
+++ b/lib/chat-widget.cpp
@@ -1035,7 +1035,7 @@ void ChatWidget::initChatArea()
         info.setTimeOpened(QDateTime::currentDateTime());
     }
 
-    info.setServiceIconImage(KIconLoader::global()->iconPath(d->account->iconName(), KIconLoader::Panel));
+    info.setServiceIconPath(KIconLoader::global()->iconPath(d->account->iconName(), KIconLoader::Panel));
     d->ui.chatArea->initialise(info);
 
     //set the title of this chat.

diff --git a/lib/adium-theme-header-info.h b/lib/adium-theme-header-info.h
index 177d699..ecb27e5 100644
--- a/lib/adium-theme-header-info.h
+++ b/lib/adium-theme-header-info.h
@@ -73,9 +73,9 @@ public:
     QDateTime timeOpened() const;
     void setTimeOpened(const QDateTime &timeOpened);
 
-    /** The protocol image of the service */
-    QString serviceIconImg() const;
-    void setServiceIconImage(const QString &serviceIconImg);
+    /** Path to the protocol image of the service */
+    QString serviceIconPath() const;
+    void setServiceIconPath(const QString &serviceIconPath);
 
     /** The chat is a group chat */
     bool isGroupChat() const;
-- 
ktp-text-ui packaging



More information about the pkg-kde-commits mailing list